@@ -19,7 +19,7 @@ use Net::Proxmox::VE::Cluster;
 use Net::Proxmox::VE::Nodes;
 
 
-our $VERSION = 0.003;
+our $VERSION = 0.005;
 
 =encoding utf8
 
@@ -57,6 +57,12 @@ Perltidy with default settings is prefered style.
 
 Oh, our tests are all against a running server. Care to help make them better?
 
+=head1 DESIGN NOTE
+
+This API would be far nicer if it returned nice objects representing different aspects of the system.
+Such an arrangement would be far better than how this module is currently layed out. It might also be
+less repetitive code.
+
 =head1 DESCRIPTION
 
 This Class provides the framework for talking to Proxmox VE 2.0 API instances.
@@ -258,7 +264,7 @@ sub delete {
     if ( $self->nodes ) {
         return $self->action( path => join( '/', @path ), method => 'DELETE' );
     }
-    return;
+    return
 }
 
 =head2 get
@@ -270,10 +276,13 @@ value of action with the GET method
 
 sub get {
     my $self = shift or return;
+    my $post_data;
+    $post_data = pop
+        if ref $_[-1];
     my @path = @_    or return;    # using || breaks this
 
     if ( $self->nodes ) {
-        return $self->action( path => join( '/', @path ), method => 'GET' );
+        return $self->action( path => join( '/', @path ), method => 'GET', post_data => $post_data );
     }
     return;
 }
@@ -374,19 +383,21 @@ You are returned what action() with the POST method returns
 sub post {
 
     my $self      = shift or return;
-    my $path      = shift or return;
-    my $post_data = shift or return;
+    my $post_data;
+    $post_data = pop
+        if ref $_[-1];
+    my @path = @_    or return;    # using || breaks this
 
     if ( $self->nodes ) {
 
         return $self->action(
-            path      => $path,
+            path      => join( '/', @path ),
             method    => 'POST',
             post_data => $post_data
           )
 
     }
-    return;
+    return
 }
 
 =head2 put
@@ -399,8 +410,23 @@ your returned what post returns
 =cut
 
 sub put {
-    my $self = shift;
-    return $self->post(@_);
+
+    my $self      = shift or return;
+    my $post_data;
+    $post_data = pop
+        if ref $_[-1];
+    my @path = @_    or return;    # using || breaks this
+
+    if ( $self->nodes ) {
+
+        return $self->action(
+            path      => join( '/', @path ),
+            method    => 'PUT',
+            post_data => $post_data
+          )
+
+    }
+    return
 }
 
 
